==> qtjambi-graphs-debuginfo-linux-x64-6.6.1.jar: sources/QtJambiGraphs/QSurfaceDataRow_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGraphs/qsurfacedataproxy.h>
#include <QtCore/QVariant>
#include "hashes.h"

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QSurfaceDataRow(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSurfaceDataRow")
    QSurfaceDataRow *_ptr = reinterpret_cast<QSurfaceDataRow *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QSurfaceDataRow_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QList<QSurfaceDataItem> *__qt_this = new(__qtjambi_ptr) QList<QSurfaceDataItem>();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QList<QSurfaceDataItem>
void __qt_destruct_QSurfaceDataRow(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QList<QSurfaceDataItem>")
    reinterpret_cast<QList<QSurfaceDataItem>*>(ptr)->~QList();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QList<QSurfaceDataItem>::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_graphs_QSurfaceDataRow_initialize_1native__Lio_qt_graphs_QSurfaceDataRow_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QList<QSurfaceDataItem>::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSurfaceDataRow_0, sizeof(QSurfaceDataRow), typeid(QSurfaceDataRow), false, QtJambiPrivate::QListAccess<QSurfaceDataItem>::newInstance(), &deleter_QSurfaceDataRow, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_graphs_QSurfaceDataRow_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QSurfaceDataRow *__qt_this = QtJambiAPI::objectFromNativeId<QSurfaceDataRow>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_graphs_QSurfaceDataRow_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QList<QSurfaceDataItem> *__qt_this = QtJambiAPI::objectFromNativeId<QSurfaceDataRow>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QList<QSurfaceDataItem>(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QSurfaceDataRow(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QSurfaceDataRow>("QSurfaceDataRow", "io/qt/graphs/QSurfaceDataRow");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QSurfaceDataRow, {
        ConstructorInfo(&__qt_construct_QSurfaceDataRow_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSurfaceDataRow);
    registerContainerAccessFactory(typeId, NewContainerAccessFunction(&QtJambiPrivate::QListAccess<QSurfaceDataItem>::newInstance));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-graphs-debuginfo-linux-x64-6.6.2.jar: sources/QtJambiGraphs/QSurfaceDataRow_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGraphs/qsurfacedataproxy.h>
#include <QtCore/QVariant>
#include "hashes.h"

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QSurfaceDataRow(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSurfaceDataRow")
    QSurfaceDataRow *_ptr = reinterpret_cast<QSurfaceDataRow *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QSurfaceDataRow()
void __qt_construct_QSurfaceDataRow(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QSurfaceDataRow()")
    Q_UNUSED(__java_arguments)
    QList<QSurfaceDataItem> *__qt_this = new(__qtjambi_ptr) QList<QSurfaceDataItem>();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QList<QSurfaceDataItem>::QSurfaceDataRow()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_graphs_QSurfaceDataRow_initialize_1native__Lio_qt_graphs_QSurfaceDataRow_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QList<QSurfaceDataItem>::QSurfaceDataRow()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSurfaceDataRow, sizeof(QSurfaceDataRow), typeid(QSurfaceDataRow), false, QtJambiPrivate::QListAccess<QSurfaceDataItem>::newInstance(), &deleter_QSurfaceDataRow, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QSurfaceDataRow(QSurfaceDataRow)
void __qt_construct_QSurfaceDataRow_cref_QSurfaceDataRow(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QSurfaceDataRow(QSurfaceDataRow)")
    jobject other0 = __java_arguments[0].l;
    const QSurfaceDataRow& __qt_other0 = qtjambi_cast<const QSurfaceDataRow& >(__jni_env, other0);
    QList<QSurfaceDataItem> *__qt_this = new(__qtjambi_ptr) QList<QSurfaceDataItem>(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QList<QSurfaceDataItem>::QSurfaceDataRow(QSurfaceDataRow)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_graphs_QSurfaceDataRow_initialize_1native__Lio_qt_graphs_QSurfaceDataRow_2Lio_qt_graphs_QSurfaceDataRow_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QList<QSurfaceDataItem>::QSurfaceDataRow(QSurfaceDataRow)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSurfaceDataRow_cref_QSurfaceDataRow, sizeof(QSurfaceDataRow), typeid(QSurfaceDataRow), false, QtJambiPrivate::QListAccess<QSurfaceDataItem>::newInstance(), &deleter_QSurfaceDataRow, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QList<QSurfaceDataItem>
void __qt_destruct_QSurfaceDataRow(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QList<QSurfaceDataItem>")
    reinterpret_cast<QList<QSurfaceDataItem>*>(ptr)->~QList();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_graphs_QSurfaceDataRow_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QSurfaceDataRow *__qt_this = QtJambiAPI::objectFromNativeId<QSurfaceDataRow>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_graphs_QSurfaceDataRow_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QSurfaceDataRow *__qt_this = QtJambiAPI::objectFromNativeId<QSurfaceDataRow>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QList<QSurfaceDataItem>(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QSurfaceDataRow(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QSurfaceDataRow>("QSurfaceDataRow", "io/qt/graphs/QSurfaceDataRow");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QSurfaceDataRow, {
        ConstructorInfo(&__qt_construct_QSurfaceDataRow, nullptr)
       ,ConstructorInfo(&__qt_construct_QSurfaceDataRow_cref_QSurfaceDataRow, "Lio/qt/graphs/QSurfaceDataRow;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSurfaceDataRow);
    registerContainerAccessFactory(typeId, NewContainerAccessFunction(&QtJambiPrivate::QListAccess<QSurfaceDataItem>::newInstance));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
